﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using C1.Win.C1Document;
using System.Collections.Specialized;
using C1.Win.FlexReport;
using C1.Web.Api.Report.Models;
using C1.Web.Api.Report;
using C1.Win.C1Document.Export;
using System.Data;
using System.IO;
using System.Drawing;
using System.Data.SqlClient;

namespace CustomReportProvider.Models
{
    public class GroupReportsProvider : ReportProvider
    {
        /// <summary>
        /// Gets catalog info of the specified path.
        /// </summary>
        /// <param name="providerName">The key used to register the provider.</param>
        /// <param name="path">The relative path of the folder or report.</param>
        /// <param name="recursive">Whether to return the entire tree of child items below the specified item.</param>
        /// <param name="args">The collection of HTTP query string variables.</param>
        /// <returns>A <see cref="CatalogItem"/> object.</returns>
        public override CatalogItem GetCatalogItem(string providerName, string path, bool recursive, NameValueCollection args = null)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Creates the document for the specified report path.
        /// </summary>
        /// <param name="path">The relative path of the report, without the registered key for the report provider.</param>
        /// <param name="args">The collection of HTTP query string variables.</param>
        /// <returns>A <see cref="C1DocumentSource"/> created for the specified path.</returns>
        protected override C1DocumentSource CreateDocument(string path, NameValueCollection args)
        {
            var index = path.LastIndexOf("/");
            var filePath = path.Substring(0, index);
            var reportName = path.Substring(index + 1);
            var fileName = System.IO.Path.Combine(AppDomain.CurrentDomain.SetupInformation.ApplicationBase, filePath);
            var report = new C1FlexReport();
            report.Load(fileName, reportName);
            report.DataSource.Recordset = GetDataTable();


            //Create a group in the existing report
            Section s;
            // group fields by categoryid and sort them in ascending order         
            Group grp = report.Groups.Add("GrpcategoryID", "CategoryID", SortEnum.Ascending);
            grp.KeepTogether = KeepTogetherEnum.KeepWholeGroup;

            // format the Header section for the new group           
            s = grp.SectionHeader;
            s.Height = 1440;
            s.Visible = true;

            //Create fields to display CategoryID
            TextField textFld1 = new TextField();
            textFld1.Name = "LblCategoryID";
            textFld1.Text = "CategoryID:";
            textFld1.Left = 0;
            textFld1.Top = 0;
            textFld1.Width = 8000;
            textFld1.Height = 1440;
            textFld1.Font.Size = 16;
            textFld1.Font.Bold = true;
            textFld1.ForeColor = Color.Black;
            s.Fields.Add(textFld1);
            TextField textFld2 = new TextField();
            textFld2.Name = "FldCategoryID";
            textFld2.Text = "=CategoryID";
            textFld2.Left = 0;
            textFld2.Top = 0;
            textFld2.Width = 8000;
            textFld2.Height = 1440;
            textFld2.Font.Size = 16;
            textFld2.Font.Bold = true;
            textFld2.ForeColor = Color.Black;
            s.Fields.Add(textFld2);

            ImageField img = (ImageField)report.Fields["ImgFld"];
            img.Picture = File.ReadAllBytes(HttpContext.Current.Server.MapPath("~/Content/c1logo.png"));
            return report;
        }

        private DataTable GetDataTable()
        {
            DataTable dt = new DataTable();
            string ConnectionString = System.Configuration.ConfigurationManager.
    ConnectionStrings["ConnectionString"].ConnectionString;
            string query = "Select * from Products";
            SqlConnection conn = new SqlConnection(ConnectionString);
            conn.Open();
            SqlDataAdapter adapter = new SqlDataAdapter(query, conn);
            adapter.Fill(dt);
            adapter.Dispose();
            conn.Close();
            return dt;

        }
    }
}